Attribute VB_Name = "addon_macros"


Public Sub CopyPage()
    
    Dim currPage As Visio.Page
    Dim newPage As Visio.Page
    Dim maxNr As Integer
    Dim currBackPage As String
    Dim currPageName As String
    Dim allShapes As Visio.Selection
    Dim groupedShapes As Visio.Shape
    
    ' Group all shapes on the current page and copy them to clipboard
    ActiveWindow.SelectAll
    Set allShapes = ActiveWindow.Selection
    Set groupedShapes = allShapes.Group
    groupedShapes.Copy visCopyPasteNoTranslate
    groupedShapes.Ungroup
    
    ' Create the new page
    Set currPage = ActivePage
    Set newPage = ActiveDocument.Pages.Add
    If Not (currPage.Background) Then
        'if current page is a background page, don't set index
        newPage.Index = currPage.Index + 1
    End If
    
    ' Create a proper name for the new page
    currPageName = currPage.Name
    maxNr = Len(currPageName)
    If (maxNr > 24) Then
        maxNr = 24
    End If
    newPage.Name = Left(currPageName, maxNr) + " (copy)"
    
    'Paste the grouped shapes
    newPage.Paste visCopyPasteNoTranslate
    If newPage.Shapes.Count Then
        newPage.Shapes.Item(1).Ungroup
    End If
    ActiveWindow.DeselectAll
          
End Sub


Public Sub CopyPageToDoc()
    
    Dim currPage As Visio.Page
    Dim newPage As Visio.Page
    Dim maxNr As Integer
    Dim currBackPage As String
    Dim currPageName As String
    Dim allShapes As Visio.Selection
    Dim groupedShapes As Visio.Shape
    
    ' Group all shapes on the current page and copy them to clipboard
    ActiveWindow.SelectAll
    Set allShapes = ActiveWindow.Selection
    Set groupedShapes = allShapes.Group
    groupedShapes.Copy visCopyPasteNoTranslate
    groupedShapes.Ungroup
    ActiveWindow.DeselectAll

    ' Select the document to copy to
    Dim i As Integer
    Dim docObj As Visio.Document

    'ctlDocList: Name of the list box that receives
    'the document names
    ufCopyPage.lb_docs.Clear

    For i = 1 To Documents.Count
        'Get next open document
        Set docObj = Documents.Item(i)
        'Add its name to the list box
        ufCopyPage.lb_docs.AddItem docObj.Name
    Next i
    ufCopyPage.Show
End Sub

Public Sub copyPageToDoc2(destDocName)
    
    'Get the destination document
    Set destDocObj = Documents.Item(destDocName)
    ' Create the new page
    
    Set currPage = ActivePage
    Set newPage = destDocObj.Pages.Add
    
    ' Create a proper name for the new page
    currPageName = currPage.Name
    newPage.Name = currPageName
    
    'Paste the grouped shapes
    newPage.Paste visCopyPasteNoTranslate
    If newPage.Shapes.Count Then
        newPage.Shapes.Item(1).Ungroup
    End If
    ActiveWindow.DeselectAll
    
        
End Sub

Public Sub PasteAsText()
    Dim objShps As Visio.Selection
    Dim obj As Visio.Shape
    Dim dummy As Visio.Shape
    Dim oldStyle As String
    
    'get the Selection
    Set objShps = Visio.ActiveWindow.Selection
    If (objShps.Count = 1) Then
        Set obj = objShps(1)
        oldStyle = obj.TextStyle
        Debug.Print oldStyle
        
        If (ActiveWindow.SelectedText.CharCount < ActiveWindow.SelectedText.Shape.CharCount) Then
            Debug.Print "Selected Text" & ActiveWindow.SelectedText.CharCount
            ActiveWindow.SelectedText.Paste
            ActiveWindow.SelectedText.Shape.TextStyle = oldStyle
        Else
            Debug.Print "No sub selection"
            ActiveWindow.SelectedText.Paste
            ActiveWindow.SelectedText.Shape.TextStyleKeepFmt = oldStyle
        End If
    Else
        ActivePage.PasteSpecial (visPasteText)
    End If
End Sub

Public Sub DeletePages()

Dim PageToIndex As Visio.Page

' loop through all the pages you have and set the layer invisible
For Each PageToIndex In ActiveDocument.Pages

    ActiveDocument.Pages(PageToIndex.Index).Delete (False)

Next

End Sub
Public Sub FitToPageAll()
    
Dim PageToIndex As Visio.Page
Dim curPage As Visio.Page

Set curPage = ActivePage

' loop through all the pages you have and set the zoom factor
For Each PageToIndex In ActiveDocument.Pages
    ActiveWindow.Page = ActiveDocument.Pages(PageToIndex.Index).Name
    ActiveWindow.Zoom = -1
Next
    
ActiveWindow.Page = curPage
  
End Sub
Public Sub MakeAllA3()

Application.ActiveDocument.PaperSize = visPaperSizeA3
Application.ActiveDocument.PrintFitOnPages = True
Application.ActiveDocument.PrintLandscape = True
Application.ActiveDocument.PrintPagesAcross = 1
Application.ActiveDocument.PrintPagesDown = 1

End Sub

Public Sub SaveAsHTML()

Dim webSettings As VisWebPageSettings
Dim saveasWeb As VisSaveAsWeb

ShowExportVersion
    
Set saveasWeb = New VisSaveAsWeb
Set webSettings = saveasWeb.WebPageSettings
webSettings.StoreInFolder = True
webSettings.TargetPath = Left$(Application.ActiveDocument.FullName, Len(Application.ActiveDocument.FullName) - 3) + "htm"
saveasWeb.CreatePages

ShowNormalVersion

'FixVisioHTML

End Sub

Public Sub ShowExportVersion()

Dim PageToIndex As Visio.Page

' loop through all the pages you have and set the layer invisible
For Each PageToIndex In Application.ActiveDocument.Pages

    Set ACell = Application.ActiveDocument.Pages(PageToIndex.Index).PageSheet.Cells("Layers.Visible[1]")
    ACell.Formula = "=0"
  
Next

End Sub

Public Sub ShowNormalVersion()

Dim PageToIndex As Visio.Page

' loop through all the pages you have and set the layer invisible
For Each PageToIndex In Application.ActiveDocument.Pages

    Set ACell = Application.ActiveDocument.Pages(PageToIndex.Index).PageSheet.Cells("Layers.Visible[1]")
    ACell.Formula = "=1"
  
Next

End Sub

Public Sub FixVisioHTML()
    
    Set fso = CreateObject("Scripting.FileSystemObject")

    Dim htmlDir As String
    Dim file1, file2 As String
    Dim srcFile, dstFile As String
    
    file1 = "vml_1.js"
    file2 = "widgets.html"
    htmlDir = Left$(Application.ActiveDocument.FullName, Len(Application.ActiveDocument.FullName) - 4) + "_files\"
    
    ' copy file1 over
    srcFile = "C:\Visio_Fix\" + file1
    dstFile = htmlDir + file1
    
    If (fso.FileExists(srcFile) = False) Then
       MsgBox srcFile + " not found"
    End If
    If (fso.FileExists(dstFile) = False) Then
       MsgBox dstFile + " not found"
    End If
    
    v = fso.CopyFile(srcFile, dstFile, True)
    
    ' copy file2 over
    srcFile = "C:\Visio_Fix\" + file2
    dstFile = htmlDir + file2
    
    If (fso.FileExists(srcFile) = False) Then
       MsgBox srcFile + " not found"
    End If
    If (fso.FileExists(dstFile) = False) Then
       MsgBox dstFile + " not found"
    End If
    
    v = fso.CopyFile(srcFile, dstFile, True)
        
End Sub

Public Sub Remove_MacroMenu()
    'Tell Visio to use the built-in menus.
    ThisDocument.ClearCustomMenus
    Visio.Application.ClearCustomMenus
End Sub


Public Sub Add_MacroMenu()

    Dim uiObj As Visio.UIObject
    Dim visMenuSets As Visio.MenuSets
    Dim visMenuSet As Visio.MenuSet
    Dim visMenus As Visio.Menus
    Dim visMenu As Visio.Menu
    Dim visMenuItems As Visio.MenuItems
    Dim visMenuItem As Visio.MenuItem

    Dim visAccelTblsObj As Visio.AccelTables
    Dim visAccelTblObj As Visio.AccelTable
    Dim visAccelItemsObj As Visio.AccelItems
    Dim visAccelItem As Visio.AccelItem

    Set uiObj = Visio.Application.BuiltInMenus
    Set visMenuSets = uiObj.MenuSets
    
    ' Add Copy Page to right mouse button menu
    Set visMenuSet = visMenuSets.ItemAtID(visUIObjSetCntx_PageTabs)
    Set visMenuItems = visMenuSet.Menus(0).MenuItems
    
    Set visMenuItem = visMenuItems.Add
    visMenuItem.Caption = "&Copy Page"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "CopyPage"

    ' Get accelarator tables
    Set visAccelTblsObj = uiObj.AccelTables
    
    ' Get the Visio object context menu set.
    Set visMenuSet = visMenuSets.ItemAtID(visUIObjSetDrawing)
    Set visMenus = visMenuSet.Menus
    Set visMenu = visMenuSet.Menus.AddAt(7)
    visMenu.Caption = "Macros"
    
    ' Get the items collection from the file menu
    Set visMenuItems = visMenu.MenuItems

    'Get macros menu from builtin menus
    Dim toolsMenu As Visio.MenuItems
    Dim macroMenu As Visio.MenuItem
    Dim macroSubMenu As Visio.MenuItems
    Dim documentMacros As Visio.MenuItem
    
    Set toolsMenu = visMenuSet.Menus.Item(5).MenuItems
    Set macroMenu = toolsMenu.Item(12)
    Set macroSubMenu = macroMenu.MenuItems
     
    ' Add Example Menu Item to the File menu in the 4th position
    Set visMenuItem = visMenuItems.Add
    visMenuItem.Caption = "Copy Page"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "CopyPage"

    Set visMenuItem = visMenuItems.Add
    visMenuItem.Caption = "Copy Page to Doc"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "CopyPageToDoc"
    
    Set visMenuItem = visMenuItems.Add
    visMenuItem.BeginGroup = True
    visMenuItem.Caption = "Fit to page all"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "FitToPageAll"
  
    Set visMenuItem = visMenuItems.Add
    visMenuItem.Caption = "Save as HTML"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "SaveAsHTML"

    Set visMenuItem = visMenuItems.Add
    visMenuItem.Caption = "Create Table of Contents"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "CreateTableOfContents"
    
    ' Get keyboard shortcut tables
    Set visAccelTblObj = visAccelTblsObj.ItemAtID(visUIObjSetDrawing)
    Set visAccelItemsObj = visAccelTblObj.AccelItems
    
    Set visMenuItem = visMenuItems.Add
    visMenuItem.BeginGroup = True
    visMenuItem.Caption = "Copy in place                  Ctrl+Shift+C"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "CopyNoTranslate"
    
    ' Create keyboard shortcuts for CopyNoTranslate
    Set visAccelItem = visAccelItemsObj.Add
    visAccelItem.Control = True
    visAccelItem.Shift = True
    visAccelItem.Key = 67
    visAccelItem.AddOnName = "CopyNoTranslate"
    
    Set visMenuItem = visMenuItems.Add
    visMenuItem.Caption = "Paste in place                  Ctrl+Shift+V"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "PasteNoTranslate"
    
    ' Create keyboard shortcuts for PasteNoTranslate
    Set visAccelItem = visAccelItemsObj.Add
    visAccelItem.Control = True
    visAccelItem.Shift = True
    visAccelItem.Key = 86
    visAccelItem.AddOnName = "PasteNoTranslate"

    Set visMenuItem = visMenuItems.Add
    visMenuItem.Caption = "Paste as Unformatted Text"
    visMenuItem.State = Visio.visButtonUp
    visMenuItem.AddOnName = "PasteAsText"

    ' Set the new menus.
    Visio.Application.SetCustomMenus uiObj
    
    ' Tell Visio to use the new UI when the document is active.
    ThisDocument.SetCustomMenus uiObj
    
End Sub


Public Sub TurnOffLayer()
 
Dim LayerName As String
Dim LayerString As String
Dim LayerString2 As String
Dim LayerIndex As Integer
Dim PageToIndex As Visio.Page
 
' define the layer to turn off
LayerName = "placeholder"
 
' loop through all the pages you have and set the layer invisible
For Each PageToIndex In Application.ActiveDocument.Pages
 
    LayerIndex = -1
    ' find layer index
    For i = 1 To Application.ActiveDocument.Pages(PageToIndex.Index).Layers.Count
        If Application.ActiveDocument.Pages(PageToIndex.Index).Layers(i).Name = LayerName Then
            LayerIndex = i
        End If
    Next
    LayerString = "Layers.Visible[" + Format(LayerIndex) + "]"
    LayerString2 = "Layers.Print[" + Format(LayerIndex) + "]"
    
    If LayerIndex <> -1 Then
        Debug.Print LayerString
        Set ACell = Application.ActiveDocument.Pages(PageToIndex.Index).PageSheet.Cells(LayerString)
        ACell.Formula = "=0"
        Set ACell = Application.ActiveDocument.Pages(PageToIndex.Index).PageSheet.Cells(LayerString2)
        ACell.Formula = "=0"
    End If
Next
 
End Sub

Public Sub TurnOnLayer()
 
Dim LayerName As String
Dim LayerString As String
Dim LayerString2 As String
Dim LayerIndex As Integer
Dim PageToIndex As Visio.Page
 
' define the layer to turn off
LayerName = "placeholder"
 
' loop through all the pages you have and set the layer invisible
For Each PageToIndex In Application.ActiveDocument.Pages
 
    LayerIndex = -1
    ' find layer index
    For i = 1 To Application.ActiveDocument.Pages(PageToIndex.Index).Layers.Count
        If Application.ActiveDocument.Pages(PageToIndex.Index).Layers(i).Name = LayerName Then
            LayerIndex = i
        End If
    Next
    LayerString = "Layers.Visible[" + Format(LayerIndex) + "]"
    LayerString2 = "Layers.Print[" + Format(LayerIndex) + "]"
    
    If LayerIndex <> -1 Then
        Debug.Print LayerString
        Set ACell = Application.ActiveDocument.Pages(PageToIndex.Index).PageSheet.Cells(LayerString)
        ACell.Formula = "=1"
        Set ACell = Application.ActiveDocument.Pages(PageToIndex.Index).PageSheet.Cells(LayerString2)
        ACell.Formula = "=1"
    End If
Next
 
End Sub

Public Sub CreateTableOfContents()

' creates a shape for each page in the drawing on the first page of the
' drawing then adds a hyperlink to each shape so you can click and go
' to that page

' define a toc shape
Dim TOCEntry As Visio.Shape
Dim PageToIndex As Visio.Page
Dim X As Integer
Dim StartX, StartY, TocWidth As Integer
Dim TocLineHeight As Double
Dim hlink As Visio.Hyperlink
Dim PageCnt As Double

' Set initial position
StartX = 2
StartY = 4
TocWidth = 7.5
TocLineHeight = 0.2

' Count all foreground pages
PageCnt = 0
For Each PageObj In ActiveDocument.Pages
    If PageObj.Background = False Then PageCnt = PageCnt + 1
Next

' loop through all the pages you have
For Each PageToIndex In Application.ActiveDocument.Pages

  ' you may want to refine this and use a top down algorithm with
  ' something smaller than 1 inch increments.
  X = PageToIndex.Index

    If (PageToIndex.Background = False) Then
    
        ' draw a rectangle for each page to hold the text
        Set TOCEntry = ActivePage.DrawRectangle(StartX, StartY + ((PageCnt - X + 1) * TocLineHeight), StartX + TocWidth, StartY + ((PageCnt - X) * TocLineHeight))

        ' write the page name in the rectangle
        TOCEntry.Text = PageToIndex.Name + Chr(9) + Str(X)
        TOCEntry.TextStyle = "Normal"
        TOCEntry.LineStyle = "Text Only"
        TOCEntry.FillStyle = "Text Only"
        TOCEntry.CellsSRC(visSectionParagraph, 0, visHorzAlign).FormulaU = "0"
        
        ' add tab stops
        TOCEntry.RowType(visSectionTab, visRowTab) = VisRowTags.visTagTab10
        TOCEntry.CellsSRC(visSectionTab, 0, visTabStopCount).FormulaU = "1"
        TOCEntry.CellsSRC(visSectionTab, 0, visTabPos).FormulaU = "131 mm"
        TOCEntry.CellsSRC(visSectionTab, 0, visTabAlign).FormulaU = "2"
          
        ' need to create a handle to add the hyperlink
        Set hlink = TOCEntry.AddHyperlink

        ' add a description
        hlink.Description = PageToIndex.Name

        ' add the page name as an address
        hlink.SubAddress = PageToIndex.Name
    End If
    
Next

End Sub

Public Sub CopyNoTranslate()
Attribute CopyNoTranslate.VB_ProcData.VB_Invoke_Func = "C"

    Application.ActiveWindow.Selection.Copy (visCopyPasteNoTranslate)

End Sub

 

Public Sub PasteNoTranslate()
Attribute PasteNoTranslate.VB_ProcData.VB_Invoke_Func = "V"

    Application.ActivePage.Paste (visCopyPasteNoTranslate)

End Sub

